rustre_core::node_state

Function check_node_function_state

pub fn check_node_function_state(
    engine: TrackedMut<'_, Engine<'_>>,
    instance: NodeInstance,
)
Query: Checks the coherence between the use of the function or node keyword and the presence or absence of temporal state