pub fn is_node_stateful(
_engine: TrackedMut<'_, Engine<'_>>,
_instance: NodeInstance,
) -> boolExpand description
Query: Returns true if a node contains any stateful expressions (and is thus stateful
itself)
pub fn is_node_stateful(
_engine: TrackedMut<'_, Engine<'_>>,
_instance: NodeInstance,
) -> boolQuery: Returns true if a node contains any stateful expressions (and is thus stateful
itself)